@@ -5,7 +5,7 @@ Weasel::Widgets::HTML::Button - Wrapper for button-like INPUT and BUTTON tags
 
 =head1 VERSION
 
-0.01
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -23,7 +23,7 @@ Weasel::Widgets::HTML::Button - Wrapper for button-like INPUT and BUTTON tags
 
 =cut
 
-package Weasel::Widgets::HTML::Button;
+package Weasel::Widgets::HTML::Button 0.32;
 
 
 use strict;
@@ -83,7 +83,7 @@ L<perl-weasel@googlegroups.com|mailto:perl-weasel@googlegroups.com>.
 
 =head1 LICENSE AND COPYRIGHT
 
- (C) 2016  Erik Huelsmann
+ (C) 2016-2023  Erik Huelsmann
 
 Licensed under the same terms as Perl.
 
@@ -93,4 +93,3 @@ Licensed under the same terms as Perl.
 __PACKAGE__->meta->make_immutable;
 
 1;
-
